#ifndef TRIE_HASH_pkgTagHash
#define TRIE_HASH_pkgTagHash
#include <stddef.h>
#include <stdint.h>
#include <apt-pkg/tagfile.h>
#include <apt-pkg/header-is-private.h>
enum class pkgTagSection::Key {
    Architecture = 0,
    Architecture_Variant = 73,
    Auto_Built_Package = 1,
    Binary = 2,
    Breaks = 3,
    Build_Conflicts = 4,
    Build_Conflicts_Arch = 5,
    Build_Conflicts_Indep = 6,
    Build_Depends = 7,
    Build_Depends_Arch = 8,
    Build_Depends_Indep = 9,
    Build_Essential = 10,
    Built_For_Profiles = 11,
    Built_Using = 12,
    Checksums_Md5 = 13,
    Checksums_Sha1 = 14,
    Checksums_Sha256 = 15,
    Checksums_Sha512 = 16,
    Conffiles = 17,
    Config_Version = 18,
    Conflicts = 19,
    Depends = 20,
    Description = 21,
    Description_md5 = 22,
    Directory = 23,
    Enhances = 24,
    Essential = 25,
    Files = 27,
    Filename = 26,
    Format = 28,
    Homepage = 29,
    Important = 30,
    Installed_Size = 31,
    MD5sum = 33,
    Maintainer = 32,
    Multi_Arch = 34,
    Origin = 35,
    Original_Maintainer = 36,
    Package = 37,
    Package_List = 38,
    Package_Type = 39,
    Phased_Update_Percentage = 40,
    Pre_Depends = 41,
    Priority = 42,
    Protected = 43,
    Provides = 44,
    Recommends = 45,
    Replaces = 46,
    SHA1 = 48,
    SHA256 = 49,
    SHA512 = 50,
    Section = 47,
    Size = 51,
    Source = 52,
    Source_Version = 72,
    Standards_Version = 53,
    Status = 55,
    Static_Built_Using = 54,
    Suggests = 56,
    Tag = 57,
    Task = 58,
    Testsuite = 59,
    Testsuite_Triggers = 60,
    Uploaders = 61,
    Vcs_Bzr = 64,
    Vcs_Cvs = 65,
    Vcs_Git = 67,
    Vcs_Hg = 68,
    Vcs_Mtn = 69,
    Vcs_Svn = 70,
    Vcs_Arch = 62,
    Vcs_Browser = 63,
    Vcs_Darcs = 66,
    Version = 71,
    Unknown = -1,
};
enum pkgTagSection::Key pkgTagHash(const char *string, size_t length);
#endif                       /* TRIE_HASH_pkgTagHash */
